@@ -10,17 +10,12 @@ package <%= $c->module %>;
 use strict;
 use warnings;
 
-sub new {
-    my $class = shift;
-    my $self  = bless {}, $class;
-
-    $self;
-}
-
 1;
 
 __END__
 
+=encoding utf-8
+
 =head1 NAME
 
 <%= $c->module %>
@@ -31,8 +26,6 @@ __END__
 
 =head1 METHODS
 
-=head2 new
-
 =head1 AUTHOR
 
 <%= $c->config('author') %>, E<lt><%= $c->config('email') %>E<gt>
